@@ -17,14 +17,20 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dashboard.c,v 1.2 2004/01/14 12:20:40 chpe Exp $
+ *  $Id: ephy-dashboard.c,v 1.2.6.1 2004/09/26 16:22:39 chpe Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-dashboard-extension.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
 
+G_MODULE_EXPORT GType register_module (GTypeModule *module);
+
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
@@ -32,4 +38,3 @@ register_module (GTypeModule *module)
 
 	return ephy_dashboard_extension_register_type (module);
 }
-
