@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-selection.cpp,v 1.1 2004/09/08 12:39:12 chpe Exp $
+ *  $Id: mozilla-selection.cpp,v 1.1.2.1 2004/11/15 15:08:51 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,6 +27,9 @@
 
 #include <glib.h>
 
+#define MOZILLA_STRICT_API
+#include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsCOMPtr.h>
 #include <nsISelection.h>
 #include <gtkmozembed.h>
@@ -34,7 +37,6 @@
 #include <nsIDOMWindow.h>
 #include <nsIWebBrowserFocus.h>
 #include <gtkmozembed_internal.h>
-#include <nsEmbedString.h>
 #include <nsMemory.h>
 
 extern "C" char *
